# Schottky

This project is a collection of python modules and tools for simulation of 1D Schottky diode with some defects in the semiconductor bulk.

## Acknowledgement

The project was supported by Russian Foundation for Basic Research (grant 14-02-31511-mol_a, 2016)
and by Russian Scientific Foundation (grant No. 17- 72-10119, 2017-2019).